@@ -20,12 +20,14 @@ exports.Iconv = Iconv;
 
 var stream = require('stream');
 var util = require('util');
+var Buffer = require('safer-buffer').Buffer;
 
 var bindings;
 try {
   bindings = require('../build/Release/iconv.node');
 }
 catch (e) {
+  if (e.code !== 'MODULE_NOT_FOUND') throw e;
   bindings = require('../build/Debug/iconv.node');
 }
 
@@ -53,22 +55,21 @@ function Iconv(fromEncoding, toEncoding)
                     toEncoding + ' is not supported.');
   }
 
-  var convert_ = convert.bind({ conv_: conv });
   var context_ = { trailer: null };
 
   this.convert = function(input, encoding) {
     if (typeof(input) === 'string') {
-      input = new Buffer(input, encoding || 'utf8');
+      input = Buffer.from(input, encoding || 'utf8');
     }
-    return convert_(input, null);
+    return convert(conv, input, null);
   };
 
   this.write = function(input, encoding) {
     if (typeof(input) === 'string') {
-      input = new Buffer(input, encoding || 'utf8');
+      input = Buffer.from(input, encoding || 'utf8');
     }
     try {
-      var buf = convert_(input, context_);
+      var buf = convert(conv, input, context_);
     }
     catch (e) {
       this.emit('error', e);
@@ -97,8 +98,8 @@ function fixEncoding(encoding)
   return /^utf[^-]/i.test(encoding) ? 'utf-' + encoding.substr(3) : encoding;
 }
 
-function convert(input, context) {
-  if (!(input instanceof Buffer) && input !== FLUSH) {
+function convert(conv, input, context) {
+  if (!Buffer.isBuffer(input) && input !== FLUSH) {
     throw new Error('Bad argument.');  // Not a buffer or a string.
   }
   if (context !== null && context.trailer !== null && input === FLUSH) {
@@ -106,20 +107,20 @@ function convert(input, context) {
   }
   if (context !== null && context.trailer !== null) {
     // Prepend input buffer with trailer from last chunk.
-    var newbuf = new Buffer(context.trailer.length + input.length);
+    var newbuf = Buffer.alloc(context.trailer.length + input.length);
     context.trailer.copy(newbuf, 0, 0, context.trailer.length);
     input.copy(newbuf, context.trailer.length, 0, input.length);
     context.trailer = null;
     input = newbuf;
   }
-  var output = new Buffer(input.length * 2);  // To a first approximation.
+  var output = Buffer.alloc(input.length * 2);  // To a first approximation.
   var input_start = 0;
   var output_start = 0;
   var input_size = input.length;
   var output_size = output.length;
   var out = [0,0];
   for (;;) {
-    var errno = bindings.convert(this.conv_,
+    var errno = bindings.convert(conv,
                                  input,
                                  input_start,
                                  input_size,
@@ -137,7 +138,7 @@ function convert(input, context) {
     if (errno) {
       if (errno === E2BIG) {
         output_size += output.length;
-        var newbuf = new Buffer(output.length * 2);
+        var newbuf = Buffer.alloc(output.length * 2);
         output.copy(newbuf, 0, 0, output_start);
         output = newbuf;
         continue;
