@@ -32,7 +32,6 @@ namespace
 using v8::Array;
 using v8::Boolean;
 using v8::FunctionTemplate;
-using v8::Handle;
 using v8::Integer;
 using v8::Local;
 using v8::Null;
@@ -62,7 +61,7 @@ struct Iconv
     delete data.GetParameter();
   }
 
-  static void Initialize(Handle<Object> obj)
+  static void Initialize(Local<Object> obj)
   {
     Local<ObjectTemplate> t = Nan::New<ObjectTemplate>();
     t->SetInternalFieldCount(1);
@@ -81,8 +80,8 @@ struct Iconv
 
   static NAN_METHOD(Make)
   {
-    String::Utf8Value from_encoding(info[0]);
-    String::Utf8Value to_encoding(info[1]);
+    Nan::Utf8String from_encoding(info[0]);
+    Nan::Utf8String to_encoding(info[1]);
     iconv_t conv = iconv_open(*to_encoding, *from_encoding);
     if (conv == reinterpret_cast<iconv_t>(-1)) {
       return info.GetReturnValue().SetNull();
@@ -100,14 +99,14 @@ struct Iconv
   {
     Iconv* iv = static_cast<Iconv*>(
         Nan::GetInternalFieldPointer(info[0].As<Object>(), 0));
-    const bool is_flush = info[8]->BooleanValue();
+    const bool is_flush = Nan::To<bool>(info[8]).FromJust();
     ICONV_CONST char* input_buf =
         is_flush ? NULL : node::Buffer::Data(info[1].As<Object>());
-    size_t input_start = info[2]->Uint32Value();
-    size_t input_size = info[3]->Uint32Value();
+    size_t input_start = Nan::To<uint32_t>(info[2]).FromJust();
+    size_t input_size = Nan::To<uint32_t>(info[3]).FromJust();
     char* output_buf = node::Buffer::Data(info[4].As<Object>());
-    size_t output_start = info[5]->Uint32Value();
-    size_t output_size = info[6]->Uint32Value();
+    size_t output_start = Nan::To<uint32_t>(info[5]).FromJust();
+    size_t output_size = Nan::To<uint32_t>(info[6]).FromJust();
     Local<Array> rc = info[7].As<Array>();
     if (input_buf != NULL) input_buf += input_start;
     output_buf += output_start;
